Learn R Programming

betaNB (version 1.0.6)

coef.betanb: Estimated Parameter Method for an Object of Class betanb

Description

Estimated Parameter Method for an Object of Class betanb

Usage

# S3 method for betanb
coef(object, ...)

Value

Returns a vector of estimated parameters.

Arguments

object

Object of Class betanb, that is, the output of the BetaNB(), RSqNB(), SCorNB(), DeltaRSqNB(), PCorNB(), or DiffBetaNB() functions.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan