betanbConfidence Intervals Method for an Object of Class
betanb
# S3 method for betanb
confint(object, parm = NULL, level = 0.95, type = "pc", ...)Returns a matrix of confidence intervals.
Object of Class betanb,
that is,
the output of the
BetaNB(),
RSqNB(),
SCorNB(),
DeltaRSqNB(),
PCorNB(), or
DiffBetaNB()
functions.
a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
the confidence level required.
Charater string.
Confidence interval type, that is,
type = "pc" for percentile;
type = "bc" for bias corrected;
type = "bca" for bias corrected and accelerated.
additional arguments.
Ivan Jacob Agaloos Pesigan