Learn R Programming

betaNB (version 1.0.6)

summary.betanb: Summary Method for an Object of Class betanb

Description

Summary Method for an Object of Class betanb

Usage

# S3 method for betanb
summary(object, alpha = NULL, type = "pc", digits = 4, ...)

Value

Returns a matrix of estimates, standard errors, number of bootstrap replications, and confidence intervals.

Arguments

object

Object of Class betanb, that is, the output of the BetaNB(), RSqNB(), SCorNB(), DeltaRSqNB(), PCorNB(), or DiffBetaNB() functions.

alpha

Numeric vector. Significance level \(\alpha\). If alpha = NULL, use the argument alpha used in object.

type

Charater string. Confidence interval type, that is, type = "pc" for percentile; type = "bc" for bias corrected; type = "bca" for bias corrected and accelerated.

digits

Digits to print.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan