Learn R Programming

betaNB (version 1.0.6)

vcov.betanb: Sampling Variance-Covariance Matrix Method for an Object of Class betanb

Description

Sampling Variance-Covariance Matrix Method for an Object of Class betanb

Usage

# S3 method for betanb
vcov(object, ...)

Value

Returns the variance-covariance matrix of estimates.

Arguments

object

Object of Class betanb, that is, the output of the BetaNB(), RSqNB(), SCorNB(), DeltaRSqNB(), PCorNB(), or DiffBetaNB() functions.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan