powered by
betanb
Estimated Parameter Method for an Object of Class betanb
# S3 method for betanb coef(object, ...)
Returns a vector of estimated parameters.
Object of Class betanb, that is, the output of the BetaNB(), RSqNB(), SCorNB(), DeltaRSqNB(), PCorNB(), or DiffBetaNB() functions.
BetaNB()
RSqNB()
SCorNB()
DeltaRSqNB()
PCorNB()
DiffBetaNB()
additional arguments.
Ivan Jacob Agaloos Pesigan