powered by
betanb
Sampling Variance-Covariance Matrix Method for an Object of Class betanb
# S3 method for betanb vcov(object, ...)
Returns the variance-covariance matrix of estimates.
Object of Class betanb, that is, the output of the BetaNB(), RSqNB(), SCorNB(), DeltaRSqNB(), PCorNB(), or DiffBetaNB() functions.
BetaNB()
RSqNB()
SCorNB()
DeltaRSqNB()
PCorNB()
DiffBetaNB()
additional arguments.
Ivan Jacob Agaloos Pesigan